Skip to main contentCrate tiled_map_web_viewer
Source - MapBadge
- One compact badge rendered next to a map entry.
- MapCategory
- A named group of maps shown inside a section in the map list panel.
- MapDetail
- One detail row shown in the details panel.
- MapManifest
- Top-level manifest file consumed by the viewer.
- MapManifestEntry
- One map entry loaded from a structured manifest.
- MapSection
- A named group of maps shown as a collapsible section in the map list panel.
- ViewerConfig
- Top-level configuration for the viewer application.
- run
- Entry point — builds and runs the Bevy application with the given configuration.